==> plasma-workspace-5.1.0.1.tar.xz: plasma-workspace-5.1.0/plasma.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=XSession
Exec=${CMAKE_INSTALL_FULL_BINDIR}/startkde
TryExec=${CMAKE_INSTALL_FULL_BINDIR}/startkde
DesktopNames=KDE
Name=Plasma
Name[ar]=بلازما
Name[ca]=Plasma
Name[cs]=Plasma
Name[da]=Plasma
Name[de]=Plasma
Name[el]=Plasma
Name[en_GB]=Plasma
Name[es]=Plasma
Name[fi]=Plasma
Name[fr]=Plasma
Name[hu]=Plasma
Name[id]=Plasma
Name[ko]=Plasma
Name[nb]=Plasma
Name[nds]=Plasma
Name[nl]=Plasma
Name[pl]=Plazma
Name[pt]=Plasma
Name[pt_BR]=Plasma
Name[ru]=Plasma
Name[sk]=Plasma
Name[sl]=Plasma
Name[sr]=Плазма
Name[sr@ijekavian]=Плазма
Name[sr@ijekavianlatin]=Plasma
Name[sr@latin]=Plasma
Name[sv]=Plasma
Name[uk]=Плазма
Name[x-test]=xxPlasmaxx
Comment=Plasma by KDE
Comment[ar]=بلازما كدي
Comment[ca]=Plasma pel KDE
Comment[da]=Plasma fra KDE
Comment[de]=Plasma von KDE
Comment[el]=Plasma από το KDE
Comment[en_GB]=Plasma by KDE
Comment[es]=Plasma, por KDE
Comment[fi]=KDE:n Plasma
Comment[fr]=Plasma, par KDE
Comment[hu]=Plasma a KDE-től
Comment[id]=Plasma oleh KDE
Comment[ko]=KDE Plasma
Comment[nb]=Plasma av KDE
Comment[nds]=Plasma vun KDE
Comment[nl]=Plasma door KDE
Comment[pl]=Plazma dzięki KDE
Comment[pt]=Plasma do KDE
Comment[pt_BR]=Plasma do KDE
Comment[ru]=KDE Plasma
Comment[sk]=Plasma od KDE
Comment[sl]=KDE Plasma
Comment[sr]=Плазма од КДЕ‑а
Comment[sr@ijekavian]=Плазма од КДЕ‑а
Comment[sr@ijekavianlatin]=Plasma od KDE‑a
Comment[sr@latin]=Plasma od KDE‑a
Comment[sv]=Plasma av KDE
Comment[uk]=Плазма KDE
Comment[x-test]=xxPlasma by KDExx
X-KDE-PluginInfo-Version=${PROJECT_VERSION}

==> plasma-workspace-5.1.1.tar.xz: plasma-workspace-5.1.1/plasma.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=XSession
Exec=${CMAKE_INSTALL_FULL_BINDIR}/startkde
TryExec=${CMAKE_INSTALL_FULL_BINDIR}/startkde
DesktopNames=KDE
Name=Plasma
Name[ar]=بلازما
Name[ca]=Plasma
Name[cs]=Plasma
Name[da]=Plasma
Name[de]=Plasma
Name[el]=Plasma
Name[en_GB]=Plasma
Name[es]=Plasma
Name[fi]=Plasma
Name[fr]=Plasma
Name[hu]=Plasma
Name[id]=Plasma
Name[ko]=Plasma
Name[lt]=Plasma
Name[nb]=Plasma
Name[nds]=Plasma
Name[nl]=Plasma
Name[pl]=Plazma
Name[pt]=Plasma
Name[pt_BR]=Plasma
Name[ru]=Plasma
Name[sk]=Plasma
Name[sl]=Plasma
Name[sr]=Плазма
Name[sr@ijekavian]=Плазма
Name[sr@ijekavianlatin]=Plasma
Name[sr@latin]=Plasma
Name[sv]=Plasma
Name[uk]=Плазма
Name[x-test]=xxPlasmaxx
Name[zh_CN]=Plasma
Comment=Plasma by KDE
Comment[ar]=بلازما كدي
Comment[ca]=Plasma pel KDE
Comment[cs]=Plasma z KDE
Comment[da]=Plasma fra KDE
Comment[de]=Plasma von KDE
Comment[el]=Plasma από το KDE
Comment[en_GB]=Plasma by KDE
Comment[es]=Plasma, por KDE
Comment[fi]=KDE:n Plasma
Comment[fr]=Plasma, par KDE
Comment[hu]=Plasma a KDE-től
Comment[id]=Plasma oleh KDE
Comment[ko]=KDE Plasma
Comment[lt]=Plasma sukurta KDE
Comment[nb]=Plasma av KDE
Comment[nds]=Plasma vun KDE
Comment[nl]=Plasma door KDE
Comment[pl]=Plazma dzięki KDE
Comment[pt]=Plasma do KDE
Comment[pt_BR]=Plasma do KDE
Comment[ru]=KDE Plasma
Comment[sk]=Plasma od KDE
Comment[sl]=KDE Plasma
Comment[sr]=Плазма од КДЕ‑а
Comment[sr@ijekavian]=Плазма од КДЕ‑а
Comment[sr@ijekavianlatin]=Plasma od KDE‑a
Comment[sr@latin]=Plasma od KDE‑a
Comment[sv]=Plasma av KDE
Comment[uk]=Плазма KDE
Comment[x-test]=xxPlasma by KDExx
Comment[zh_CN]=KDE 的 Plasma
X-KDE-PluginInfo-Version=${PROJECT_VERSION}
